'use strict';
const Generator = require('yeoman-generator');
const yosay = require('yosay');
const path = require('path');
const fs = require('fs');
//读写json配置文件通用方法；
const jsonData=(jsonFile,type,data)=>{
  return new Promise((resolve,reject)=>{
    switch(type){
      case 'r':
        fs.readFile(jsonFile,(err,data)=>{
          if(err){
            reject(err);
          }else{
            resolve(JSON.parse(data));
          }
        });
      break;
      case 'w':
        const _data=JSON.stringify(data,null,2);
        fs.writeFile(jsonFile,_data,(err)=>{
          if(err){
            reject(err);
          }
        });
      break;
      default:
        this.log('only accept r & w');
    }
  });
}
module.exports = class extends Generator {
  initializing() {
    this.log(yosay(
      '欢迎使用Yi-frames初始化您的业务新项目~~！@……@'
    ));
  }
  prompting() {
    const prompAppConfig=[
      {
        type    : 'input',
        name    : 'name',
        message : '请输入您的项目名称',
        default : this.appname, // Default to current folder name
      },
      {
        type    : 'list',
        name    : 'cliTemplate',
        message : '请选择您项目所要使用的脚手架模板：',
        choices: [
                    {
                        name: 'Default模板：基于jquery进行开发',
                        value: 'default'
                    },
                    {
                        name: 'Vue2.X模板：适用于构建完整的SPA',
                        value: 'vue'
                    }
                ] 
      },
      {
        type    : 'list',
        name    : 'scene',
        message : '请选择您项目所要使用的端：',
        choices: [
                {
                    name: '移动端',
                    value: 'mobile'
                },
                {
                    name: 'PC端',
                    value: 'pc'
                },
                {
                    name: '平台端',
                    value: 'platform'
                }
            ]       
      },
      {
        type    : 'confirm',
        name    : 'isNotSPA',
        message : '您的项目是多页应用吗?(y/n)',
        default : true, 
      },
      {
        type    : 'confirm',
        name    : 'installDeps',
        message : '您需要Yi-frames自动帮您安装node_modules依赖吗?(y/n)',
        default : false, 
      }
    ];
    return this.prompt(prompAppConfig)
      .then((answers) => {
        if(answers.name===this.appname) throw '新建项目名称不能为空，不能为父级目录名称！';
        this.name=answers.name;
        this.cliTemplate=answers.cliTemplate;
        this.isNotSPA=answers.isNotSPA;
        this.scene=answers.scene;
        this.installDeps=answers.installDeps;
      });
  }
generateBasic() { // 按照自己的templates目录自定义
  this.log('Yi-frames开始帮助您{'+this.name+'}初始项目~'); 
  // 拷贝目录  
  switch(this.cliTemplate){
    case 'default':
      this.fs.copy(this.templatePath("default/src"), this.destinationPath(this.name+"/src"));
      //配置多页应用
      if(this.isNotSPA){
        //配置场景化选项
        if(this.scene==='mobile'){
          this.fs.copy(this.templatePath("default/isNotSPA/public/mobile"), this.destinationPath(this.name+"/src/scss/public"));
        }else if(this.scene==='pc'){
          this.fs.copy(this.templatePath("default/isNotSPA/public/jxs-pc"), this.destinationPath(this.name+"/src/scss/public"));
        }else if(this.scene==='platform'){
          this.fs.copy(this.templatePath("default/isNotSPA/public/platform"), this.destinationPath(this.name+"/src/scss/public"));
        }else{
          throw '请正确配置业务场景选项！';
        }
        this.fs.copy(this.templatePath("default/isNotSPA/js/common"), this.destinationPath(this.name+"/src/js/common"));
        this.fs.copy(this.templatePath("default/isNotSPA/images/common"), this.destinationPath(this.name+"/src/images/common"));
        this.log(this.name+'多页应用模板下载成功~');
      }else{
          this.log(this.name+'单页应用模板下载成功~');
      }
    break;
    case 'vue':
        this.fs.copy(this.templatePath("vue/build"), this.destinationPath(this.name+"/build"));
        this.fs.copy(this.templatePath("vue/config"), this.destinationPath(this.name+"/config"));
        this.fs.copy(this.templatePath("vue/src"), this.destinationPath(this.name+"/src"));
        this.fs.copy(this.templatePath("vue/test"), this.destinationPath(this.name+"/test"));
        this.fs.copy(this.templatePath("vue/.babelrc"), this.destinationPath(this.name+"/.babelrc"));
        this.fs.copy(this.templatePath("vue/.editorconfig"), this.destinationPath(this.name+"/.editorconfig"));
        this.fs.copy(this.templatePath("vue/.postcssrc.js"), this.destinationPath(this.name+"/.postcssrc.js"));
        this.fs.copy(this.templatePath("vue/index.html"), this.destinationPath(this.name+"/index.html"));
        this.fs.copy(this.templatePath("vue/package.json"), this.destinationPath(this.name+"/package.json"));
    break;
    default:
      throw '查无此模板，请输入正确指令{default|vue}';
  }
}

  generateClient() {
    this.sourceRoot(path.join(__dirname, 'templates'));
    this.destinationPath('./');
  }
  install() {
    if(this.installDeps){ 
      switch(this.cliTemplate){
        case 'default':
          const npmdirdef=process.cwd()+'/'+this.name+'/src';
          process.chdir(npmdirdef);
        break;
        case 'vue':
          const npmdirvue=process.cwd()+'/'+this.name;
          process.chdir(npmdirvue);
        break;
        default:
          this.log('找不到packgage.json');
      }
      this.installDependencies({
        npm:true,
        bower:false
      }).then(() => this.log('node_modules安装完毕~~'));
    }else{
      this.log('您未选择使用Yi-frames自动帮您安装node_modules,请使用cnpm i指令自行安装~~');
    }
  }
  end() {
     switch(this.cliTemplate){
      case 'default':
        //读写default脚手架配置文件开关
        jsonData(this.destinationPath(this.name+"/src/config/index.json"),'r')
          .then((data)=>{ 
               //切换isMobile开关         
               if(this.scene!=='mobile'){
                  data.base.isMobile=false;
               }else{
                  data.base.isMobile=true;
               }
               data.base.type=this.scene;
               jsonData(this.destinationPath(this.name+"/src/config/index.json"),'w',data);
          });
      //去掉所有本地ignoreme.txt文档  
        if(this.isNotSPA){
          fs.unlinkSync(this.destinationPath(this.name+"/src/js/common/plugins/ignoreme.txt"));
          fs.unlinkSync(this.destinationPath(this.name+"/src/js/common/mods/ignoreme.txt"));
          fs.unlinkSync(this.destinationPath(this.name+"/src/images/common/ignoreme.txt"));
        }
        fs.unlinkSync(this.destinationPath(this.name+"/src/js/conf/ignoreme.txt"));
        fs.unlinkSync(this.destinationPath(this.name+"/src/scss/modules/ignoreme.txt"));
        fs.unlinkSync(this.destinationPath(this.name+"/src/images/ignoreme.txt"));
      break;
      default:
        this.log('no~~~');
    }
    //最终提示语
    this.log(yosay(
      'WELL DONE~！~\n'+
     '您通过Yi-frames使用{'+this.cliTemplate+'}模板创建了{'+this.name+'}项目~~\n'
    ));
  }
}; 